@@ -24,20 +24,24 @@
 */
 
 /*
-** Bug reports and questions can be sent to kde-devel@kde.org
+** Bug reports and questions can be sent to <kde-devel@kde.org>
 */
 #include "InputBox.moc"
-#include <qvbox.h>
-#include <qwhatsthis.h>
-#include <ui.h>
 
-InputBox::InputBox(entries e, QWidget *parent, const char *name, bool hasCancel, WFlags f)
-  : KDialogBase(parent, name, true, QString::null, hasCancel ? Ok | Cancel : Ok, Ok, true )
+
+#include <ui.h>
+#include <kvbox.h>
+InputBox::InputBox(entries e, QWidget *parent, const char *name, bool hasCancel, Qt::WFlags f)
+  : KDialog(parent)
 {
-	QVBox *page = makeVBoxMainWidget();
+	setButtons(hasCancel ? Ok | Cancel : Ok);
+       	setDefaultButton(Ok);
+	showButtonSeparator(true);
+	KVBox *page = new KVBox(this);
+	setMainWidget(page);
 	for(entries::iterator it=e.begin(); it!=e.end(); it++) {
 		EditWidget *ed=new EditWidget((*it).label, (*it).dflt, (*it).isFile, page);
-		QWhatsThis::add(ed, (*it).help);
+		ed->setWhatsThis( (*it).help);
 		edit.insert(edit.end(), ed);
 	}
 }
